from chatgpt_tool_hub.tools.wikipedia.wikipedia import WikipediaTool
from chatgpt_tool_hub.tools.wikipedia.wrapper import WikipediaAPIWrapper
